==> ctxR_1.0.0.tar.gz: ctxR/tests/testthat/chemical-batch/chemical/search/start-with/gvfdsr7.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/search/start-with/gvfdsr7", 
    status_code = 400L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Wed, 22 May 2024 19:50:08 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "12d34703-4adf-4c8e-4f58-d7453d2a8ec7", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 052215bfd8d35ecb703b208e875bd350.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "ATL59-P8", `x-amz-cf-id` = "k4G5uxOPNLn7MAq2sfnkBFzyEt-07txpVsoXFKPR8CJxUr3_m9rofA=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 400L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Wed, 22 May 2024 19:50:08 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "12d34703-4adf-4c8e-4f58-d7453d2a8ec7", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 052215bfd8d35ecb703b208e875bd350.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "ATL59-P8", `x-amz-cf-id` = "k4G5uxOPNLn7MAq2sfnkBFzyEt-07txpVsoXFKPR8CJxUr3_m9rofA=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x42, 0x61, 0x64, 0x20, 0x52, 0x65, 
    0x71, 0x75, 0x65, 0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 
    0x20, 0x34, 0x30, 0x30, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 
    0x65, 0x74, 0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x53, 0x65, 0x61, 0x72, 0x63, 0x68, 0x65, 0x64, 0x20, 0x62, 
    0x79, 0x20, 0x53, 0x79, 0x6e, 0x6f, 0x6e, 0x79, 0x6d, 0x3a, 
    0x20, 0x46, 0x6f, 0x75, 0x6e, 0x64, 0x20, 0x30, 0x20, 0x72, 
    0x65, 0x73, 0x75, 0x6c, 0x74, 0x73, 0x20, 0x66, 0x6f, 0x72, 
    0x20, 0x27, 0x67, 0x76, 0x66, 0x64, 0x73, 0x72, 0x37, 0x27, 
    0x2e, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 0x73, 
    0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 
    0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x73, 0x74, 0x61, 
    0x72, 0x74, 0x2d, 0x77, 0x69, 0x74, 0x68, 0x2f, 0x67, 0x76, 
    0x66, 0x64, 0x73, 0x72, 0x37, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x75, 0x67, 0x67, 0x65, 0x73, 0x74, 0x69, 0x6f, 
    0x6e, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x5b, 0x20, 0x6e, 0x75, 
    0x6c, 0x6c, 0x20, 0x5d, 0x0a, 0x7d)), date = structure(1716407408, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 3.9e-05, 
    connect = 0, pretransfer = 0.00016, starttransfer = 0.313656, 
    total = 0.313685)), class = "response")

==> ctxR_1.1.1.tar.gz: ctxR/tests/testthat/chemical-batch/chemical/search/start-with/gvfdsr7.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/search/start-with/gvfdsr7", 
    status_code = 400L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Fri, 08 Nov 2024 15:34:55 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "25156b0c-dcdb-473d-7f29-ebc51132dcde", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 e84404231b384141b3b0f51e40964ef6.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "ci_affIaEQ4eREN6KkxnBWpa7ugDrivUHYLxU77LRSp5MmIa3A5h3w=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 400L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Fri, 08 Nov 2024 15:34:55 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "25156b0c-dcdb-473d-7f29-ebc51132dcde", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 e84404231b384141b3b0f51e40964ef6.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "ci_affIaEQ4eREN6KkxnBWpa7ugDrivUHYLxU77LRSp5MmIa3A5h3w=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x42, 0x61, 0x64, 0x20, 0x52, 0x65, 
    0x71, 0x75, 0x65, 0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 
    0x20, 0x34, 0x30, 0x30, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 
    0x65, 0x74, 0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x53, 0x65, 0x61, 0x72, 0x63, 0x68, 0x65, 0x64, 0x20, 0x62, 
    0x79, 0x20, 0x53, 0x79, 0x6e, 0x6f, 0x6e, 0x79, 0x6d, 0x3a, 
    0x20, 0x46, 0x6f, 0x75, 0x6e, 0x64, 0x20, 0x30, 0x20, 0x72, 
    0x65, 0x73, 0x75, 0x6c, 0x74, 0x73, 0x20, 0x66, 0x6f, 0x72, 
    0x20, 0x27, 0x67, 0x76, 0x66, 0x64, 0x73, 0x72, 0x37, 0x27, 
    0x2e, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 0x73, 
    0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 
    0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x73, 0x74, 0x61, 
    0x72, 0x74, 0x2d, 0x77, 0x69, 0x74, 0x68, 0x2f, 0x67, 0x76, 
    0x66, 0x64, 0x73, 0x72, 0x37, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x75, 0x67, 0x67, 0x65, 0x73, 0x74, 0x69, 0x6f, 
    0x6e, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x5b, 0x20, 0x6e, 0x75, 
    0x6c, 0x6c, 0x20, 0x5d, 0x0a, 0x7d)), date = structure(1731080095, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.1e-05, 
    connect = 0, pretransfer = 0.000127, starttransfer = 0.311361, 
    total = 0.311395)), class = "response")
